@@ -1,8 +1,8 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,15 +23,15 @@ is where this program resides. Below you find a code
 block that might have to be adapted.
 """
 
-from __future__ import print_function
-
-from subprocess import check_output, call
+from subprocess import check_output, call, CalledProcessError
 from shutil import copy, move, copytree, rmtree
 
 import os
 import zipfile
 import tempfile
 
+from qt import QStandardPaths
+
 # pylint:disable=invalid-name
 
 
@@ -62,11 +62,11 @@ def makeIcon(svgName, icoName):
                 os.remove(pngName(resolution2))
         os.rmdir(tmpDir)
 
-dataDir = check_output(
-    "kde4-config --expandvars --install data".split()).strip()
 iconDir = check_output(
-    "kde4-config --expandvars --install icon".split()).strip()
-oxy48 = iconDir + '/oxygen/48x48'
+    "kf5-config --expandvars --install icon".split()).strip()
+iconDir = iconDir.decode()
+
+oxy48 = iconDir + '/oxygen/base/48x48'
 oxy48Cat = oxy48 + '/categories/'
 oxy48Act = oxy48 + '/actions/'
 oxy48Apps = oxy48 + '/apps/'
@@ -76,21 +76,30 @@ DEST = 'share'
 if os.path.exists(DEST):
     rmtree(DEST)
 
-targetDir = DEST + '/kde4/apps/kmahjongglib'
-os.makedirs(DEST + '/kde4/apps')
-copytree(dataDir + '/kmahjongglib', targetDir)
+targetDir = DEST + '/kmahjongglib'
+kmjLibDir = QStandardPaths.locate(QStandardPaths.AppDataLocation, 'kmahjongglib', QStandardPaths.LocateDirectory)
+copytree(kmjLibDir, targetDir)
 for tileset in ('alphabet', 'egypt'):
     for extension in ('copyright', 'desktop', 'svgz'):
         os.remove(targetDir + '/tilesets/{}.{}'.format(tileset, extension))
 
-os.makedirs(DEST + '/kde4/apps/kajongg')
-copytree(dataDir + '/kajongg/voices', DEST + '/kde4/apps/kajongg/voices')
+os.makedirs(DEST + '/kajongg')
+voiceDir = QStandardPaths.locate(QStandardPaths.AppDataLocation, 'kajongg/voices', QStandardPaths.LocateDirectory)
+copytree(voiceDir, DEST + '/kajongg/voices')
+
+for bellSound in ('/usr/share/sounds/KDE-Im-Message-In.ogg', ):
+    if os.path.exists(bellSound):
+        os.makedirs(DEST + '/sounds')
+        copy(bellSound, DEST + '/sounds/bell.ogg')
+        break
 
 os.makedirs(DEST + '/icons')
 copy(oxy48Cat + 'applications-education.png', DEST + '/icons')
 copy(oxy48Status + 'dialog-information.png', DEST + '/icons')
 copy(oxy48Status + 'dialog-warning.png', DEST + '/icons')
 copy(oxy48Apps + 'preferences-plugin-script.png', DEST + '/icons')
+copy(oxy48Apps + 'preferences-desktop-locale.png', DEST + '/icons')
+
 
 for png in (
         'application-exit', 'games-config-background', 'arrow-right',
@@ -102,21 +111,21 @@ for png in (
         'go-up', 'go-down', 'go-next', 'go-previous'):
     copy('{}/{}.png'.format(oxy48Act, png), DEST + '/icons')
 
-oggdec = 'oggdecV1.9.9.zip'
+oggdec = 'oggdecV1.10.1.zip'
 try:
     call('wget http://www.rarewares.org/files/ogg/{}'.format(oggdec).split())
     with zipfile.ZipFile(oggdec) as ziparch:
         ziparch.extract('oggdec.exe')
 finally:
     os.remove(oggdec)
-move('oggdec.exe', DEST + '/kde4/apps/kajongg/voices')
+move('oggdec.exe', DEST + '/kajongg/voices')
 
-copy('backgroundselector.ui', DEST + '/kde4/apps/kajongg')
-copy('tilesetselector.ui', DEST + '/kde4/apps/kajongg')
+copy('backgroundselector.ui', DEST + '/kajongg')
+copy('tilesetselector.ui', DEST + '/kajongg')
 
-copy('../hisc-apps-kajongg.svgz', DEST + '/icons/kajongg.svgz')
+copy('../icons/sc-apps-kajongg.svgz', DEST + '/icons/kajongg.svgz')
 
-makeIcon('../hisc-apps-kajongg.svgz', 'kajongg')
+makeIcon('../icons/sc-apps-kajongg.svgz', 'kajongg')
 makeIcon(
     iconDir +
     '/hicolor/scalable/actions/games-kajongg-law.svgz',
@@ -125,7 +134,7 @@ copy('kajongg.ico', DEST + '/icons')
 copy('games-kajongg-law.ico', DEST + '/icons')
 
 # select sufficiently complete languages from
-# http://l10n.kde.org/stats/gui/trunk-kde4/po/kajongg.po/
+# https://websvn.kde.org/trunk/l10n-kf5
 languages = (
     'bs', 'ca', 'da', 'de', 'en_GB', 'es', 'et', 'fr', 'gl', 'it', 'kk',
     'km', 'nl', 'nb', 'nds',
@@ -136,18 +145,24 @@ languages = (
 for lang in languages:
     print('getting language', lang)
     os.makedirs(DEST + '/locale/{}/LC_MESSAGES'.format(lang))
-    for directory, filename in (
-            ('kdegames', 'kajongg'), ('kdegames', 'libkmahjongg'),
-            ('kdelibs', 'kdelibs4'), ('qt', 'kdeqt')):
-        mo_data = check_output(
-            'svn cat svn://anonsvn.kde.org/home/kde/'
-            'trunk/l10n-kde4/{}/messages/{}/{}.po'.format(
-                lang, directory, filename).split())
-        with open('x.po', 'wb') as outfile:
-            outfile.write(mo_data)
-        call(
-            'msgfmt x.po -o {}/locale/{}/LC_MESSAGES/{}.mo'.format(
-                DEST,
-                lang,
-                filename).split())
-        os.remove('x.po')
+    DEVNULL = open(os.devnull, 'wb')
+    for filename in (
+            'kdegames/kajongg',
+            'kdegames/libkmahjongg5',
+            'kdegames/desktop_kdegames_libkmahjongg'):
+        try:
+            mo_data = check_output(
+                'svn cat svn://anonsvn.kde.org/home/kde/'
+                'trunk/l10n-kf5/{}/messages/{}.po'.format(
+                    lang, filename).split(), stderr=DEVNULL)
+            print('found:', lang, filename)
+            with open('x.po', 'wb') as outfile:
+                outfile.write(mo_data)
+            call(
+                'msgfmt x.po -o {}/locale/{}/LC_MESSAGES/{}.mo'.format(
+                    DEST,
+                    lang,
+                    filename.split('/')[1]).split())
+            os.remove('x.po')
+        except CalledProcessError:
+            print('not found:', lang, filename)
